@@ -13,8 +13,8 @@
 
 #include <QDomDocument>
 #include <QMap>
-#include <QSharedPointer>
 #include <QVariant>
+#include <memory>
 
 namespace KDAV
 {
@@ -24,7 +24,7 @@ namespace KDAV
 class XMLQueryBuilder
 {
 public:
-    typedef QSharedPointer<XMLQueryBuilder> Ptr;
+    typedef std::shared_ptr<XMLQueryBuilder> Ptr;
 
     virtual ~XMLQueryBuilder();
 
@@ -111,7 +111,7 @@ public:
      * Returns a list of XML documents that represent DAV queries to
      * list all available DAV resources inside a specific DAV collection.
      */
-    virtual QVector<XMLQueryBuilder::Ptr> itemsQueries() const = 0;
+    virtual QList<XMLQueryBuilder::Ptr> itemsQueries() const = 0;
 
     /**
      * Returns the possible content types for the collection that
